Modules
=======

data module
-----------

.. automodule:: causalinf.data
   :members:
   :undoc-members:
   :show-inheritance:

did module
--------------------

.. automodule:: causalinf.did
   :members:
   :undoc-members:
   :show-inheritance:

rdd module
--------------------

.. automodule:: causalinf.rdd
   :members:
   :undoc-members:
   :show-inheritance:

iv module
--------------------

.. automodule:: causalinf.iv
   :members:
   :undoc-members:
   :show-inheritance:

